.. _orbits:

Satellite Orbits: Models, Methods, and Applications
===================================================

.. image:: /images/orbits.jpg
   :align: center

|
| Authors: Oliver Montenbruck and Eberhard Gill
| ISBN-10: 354067280X
| ISBN-13: 978-3540672807
